'---------------------------------------------------------------------
'  Copyright (C) Microsoft Corporation.  All rights reserved.
' 
'THIS CODE AND INFORMATION ARE PROVIDED AS IS WITHOUT WARRANTY OF ANY
'KIND, EITHER EXPRESSED OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
'IMPLIED WARRANTIES OF MERCHANTABILITY AND/OR FITNESS FOR A
'PARTICULAR PURPOSE.
'---------------------------------------------------------------------

Option Explicit On
Option Strict On

Imports System.Collections.Generic
Imports System.ComponentModel
Imports System.ComponentModel.Design
Imports System.Drawing
Imports System.Text
Imports System.Windows.Forms

Namespace Extensions

    Friend Class PaddingBehavior
        Inherits BoundsBehavior

        Friend Sub New(ByVal serviceProvider As IServiceProvider)
            MyBase.New(serviceProvider)

            Me.propertyName = "Padding"
            Me.transactionName = "Padding drag"
        End Sub

        Protected Overrides Sub SetBoundsProperty(ByVal pd As PropertyDescriptor)
            If pd IsNot Nothing Then
                Dim translatedBounds As Rectangle = New Rectangle( _
                    Me.behaviorServiceValue.ControlToAdornerWindow(Me.relatedControl), _
                    Me.relatedControl.Size)

                Select Case (Me.selectedEdge)
                    Case EdgeSelection.Left
                        Dim leftPadding As Integer = Me.currentPosition.X - translatedBounds.Left

                        If leftPadding >= 0 Then
                            Dim padding As Padding = New Padding( _
                                leftPadding, _
                                Me.relatedControl.Padding.Top, _
                                Me.relatedControl.Padding.Right, _
                                Me.relatedControl.Padding.Bottom)

                            pd.SetValue(Me.relatedControl, padding)
                        End If

                    Case EdgeSelection.Top
                        Dim bottomPadding As Integer = Me.currentPosition.Y - translatedBounds.Top

                        If bottomPadding >= 0 Then
                            Dim padding As Padding = New Padding( _
                                Me.relatedControl.Padding.Left, _
                                bottomPadding, _
                                Me.relatedControl.Padding.Right, _
                                Me.relatedControl.Padding.Bottom)

                            pd.SetValue(Me.relatedControl, padding)
                        End If

                    Case EdgeSelection.Right
                        Dim rightPadding As Integer = translatedBounds.Right - Me.currentPosition.X

                        If rightPadding >= 0 Then
                            Dim padding As Padding = New Padding( _
                                Me.relatedControl.Padding.Left, _
                                Me.relatedControl.Padding.Top, _
                                rightPadding, _
                                Me.relatedControl.Padding.Bottom)

                            pd.SetValue(Me.relatedControl, padding)
                        End If

                    Case EdgeSelection.Bottom
                        Dim bottomPadding As Integer = translatedBounds.Bottom - Me.currentPosition.Y

                        If bottomPadding >= 0 Then
                            Dim padding As Padding = New Padding( _
                                Me.relatedControl.Padding.Left, _
                                Me.relatedControl.Padding.Top, _
                                Me.relatedControl.Padding.Right, _
                                bottomPadding)

                            pd.SetValue(Me.relatedControl, padding)
                        End If

                    Case EdgeSelection.None

                    Case Else

                End Select
            End If
        End Sub
    End Class

End Namespace
